@@ -8,6 +8,7 @@ __all__ = (
     "DeltaCoordDitherDetailer",
 )
 
+import sys
 import warnings
 
 import numpy as np
@@ -42,16 +43,25 @@ class DitherDetailer(BaseDetailer):
     n_in_night : `int` (1200)
         The number of unique positions to generate in a night.
         Only used if per_night is False.
-
-
+    big_int : `int`
+        A big integer to use for seeding random number generator
+        in case one send in a `night` value that is negative.
     """
 
-    def __init__(self, max_dither=0.7, per_night=True, n_in_night=1200, nnights=None, seed=None):
+    def __init__(
+        self, max_dither=0.7, per_night=True, n_in_night=1200, nnights=None, big_int=700000, seed=None
+    ):
 
         if nnights is not None:
             warnings.warn("kwarg nnights deprecated", FutureWarning)
         if seed is not None:
             warnings.warn("kwarg seed deprecated", FutureWarning)
+
+        # Check we can run for 10 years no problem
+        test = 36525 < big_int < (sys.maxsize - 36525)
+        if not test:
+            raise ValueError("Value used for big_int won't work for 10 year survey.")
+
         self.survey_features = {"n_in_night": NObsCount(per_night=True)}
 
         self.current_night = -np.inf
@@ -63,11 +73,16 @@ class DitherDetailer(BaseDetailer):
         self.offset_dec = None
 
         self.current_night = -np.inf
+        self.big_int = big_int
 
     def _new_ang_rad(self, night):
 
         # Seed with the current night
-        rng = np.random.default_rng(night)
+        if night < 0:
+            seed = self.big_int + night
+        else:
+            seed = night
+        rng = np.random.default_rng(seed)
         if self.per_night:
             n_gen = 1
         else:
@@ -348,18 +363,25 @@ class EuclidDitherDetailer(BaseDetailer):
         )
 
     def __call__(self, obs_array, conditions):
+        if np.size(obs_array) == 0:
+            return obs_array
+
         # Generate offsets in RA and Dec
         ra_a, dec_a, ra_b, dec_b = self._generate_offsets(len(obs_array), conditions.night)
 
+        ra = []
+        dec = []
         for i, obs in enumerate(obs_array):
             if "DD:EDFS_a" in obs["scheduler_note"][0:9]:
-                obs_array[i]["RA"] = ra_a
-                obs_array[i]["dec"] = dec_a
+                ra.append(ra_a)
+                dec.append(dec_a)
             elif "DD:EDFS_b" in obs["scheduler_note"][0:9]:
-                obs_array[i]["RA"] = ra_b
-                obs_array[i]["dec"] = dec_b
+                ra.append(ra_b)
+                dec.append(dec_b)
             else:
                 raise ValueError("scheduler_note does not contain EDFS_a or EDFS_b.")
+        obs_array["RA"] = np.concatenate(ra)
+        obs_array["dec"] = np.concatenate(dec)
         return obs_array
 
 
@@ -403,7 +425,11 @@ class SplitDetailer(BaseDetailer):
 
 class CameraRotDetailer(BaseDetailer):
     """
-    Randomly set the camera rotation, either for each exposure, or per night.
+    Randomly set the camera rotation, either for each exposure,
+    for each time the detailer is called, or per night.
+
+    Note dithering for each exposure may not be repeatable if
+    scheduler is restarted.
 
     Parameters
     ----------
@@ -416,8 +442,11 @@ class CameraRotDetailer(BaseDetailer):
         If "all", randomize per visit. Default "night".
     telescope : `str`
         Telescope name. Options of "rubin" or "auxtel". Default "rubin".
-    nnights : `int`
-        Number of dither positions to generate.
+    n_in_night : `int`
+        Number of dither positions to generate. Should be greater than
+        the maximum number of visits expected in a night (if
+        dither set to "call"), or greather than number of ngihts
+        in survey if dither set to "night". Default 7350.
     """
 
     def __init__(
@@ -427,11 +456,15 @@ class CameraRotDetailer(BaseDetailer):
         dither="night",
         per_night=None,
         seed=42,
-        nnights=7305,
+        nnights=None,
         telescope="rubin",
+        n_in_night=7350,
     ):
         self.survey_features = {}
 
+        if nnights is not None:
+            warnings.warn("nnights deprecated", FutureWarning)
+
         if per_night is True:
             warnings.warn("per_night deprecated, setting dither='night'", FutureWarning)
             dither = "night"
@@ -453,10 +486,11 @@ class CameraRotDetailer(BaseDetailer):
         self.range = self.max_rot - self.min_rot
         self.dither = dither
         self.rng = np.random.default_rng(seed)
+        self.n_in_night = n_in_night
         if dither == "call":
-            self.offsets = self.rng.random((nnights, nnights))
+            self.offsets = None
         else:
-            self.offsets = self.rng.random(nnights)
+            self.offsets = self.rng.random(n_in_night)
 
         self.offset = None
         self.rc = rotation_converter(telescope=telescope)
@@ -473,9 +507,11 @@ class CameraRotDetailer(BaseDetailer):
             if night != self.current_night:
                 self.current_night = night
                 self.call_num = 0
-            self.offset = self.offsets[night][self.call_num] * self.range + self.min_rot
+                self.rng = np.random.default_rng(night)
+                self.offsets = self.rng.random(self.n_in_night)
+            offsets = self.offsets[self.call_num] * self.range + self.min_rot
             self.call_num += 1
-            offsets = np.ones(n_offsets) * self.offset
+            offsets = np.ones(n_offsets) * offsets
         elif self.dither == "all":
             self.rng = np.random.default_rng()
             offsets = self.rng.random(n_offsets) * self.range + self.min_rot
