@@ -12,7 +12,7 @@ import pandas as pd
 from astropy.time import Time
 
 from rubin_scheduler.scheduler.utils import HpInComcamFov, HpInLsstFov, IntRounded, ObservationArray
-from rubin_scheduler.utils import DEFAULT_NSIDE, _hpid2_ra_dec, rotation_converter
+from rubin_scheduler.utils import DEFAULT_NSIDE, SURVEY_START_MJD, _hpid2_ra_dec, rotation_converter
 
 
 class CoreScheduler:
@@ -49,6 +49,8 @@ class CoreScheduler:
         Dict for mapping band name to filter name if filter has not been
         specified. Default of None maps 'ugrizy' to the same. Empty dict
         will do no mapping for missing "filter" values.
+    survey_start_mjd : `float`
+            The starting MJD of the survey.
     """
 
     def __init__(
@@ -61,8 +63,10 @@ class CoreScheduler:
         telescope="rubin",
         target_id_counter=0,
         band_to_filter=None,
+        survey_start_mjd=SURVEY_START_MJD,
     ):
         self.keep_rewards = keep_rewards
+        self.survey_start_mjd = survey_start_mjd
         # Use integer ns just to be sure there are no rounding issues.
         self.mjd_perf_counter_offset = np.int64(Time.now().mjd * 86400000000000) - time.perf_counter_ns()
 
@@ -225,6 +229,10 @@ class CoreScheduler:
         """
         # Add the current queue and scheduled queue to the conditions
         self.conditions = conditions_in
+
+        # Use our own def of survey start
+        self.conditions.survey_start_mjd = self.survey_start_mjd
+
         # put the local queue in the conditions
         self.conditions.queue = self.queue
 
