@@ -55,6 +55,7 @@ class TestDetailers(unittest.TestCase):
             detailers.BandToFilterDetailer,
             detailers.TagRadialDetailer,
             detailers.LabelDDFDetailer,
+            detailers.TruncatePreTwiDetailer,
         ]
 
         for det in det_list:
@@ -486,6 +487,75 @@ class TestDetailers(unittest.TestCase):
 
         assert np.all(np.not_equal(ra_a, ra_ap))
 
+        # Check that negative nights are ok
+        detailer = detailers.DitherDetailer(per_night=True)
+        detailer._new_ang_rad(-10)
+        ang1 = detailer.angles.copy()
+        detailer._new_ang_rad(10)
+        ang2 = detailer.angles.copy()
+
+        assert np.all(ang1 != ang2)
+
+    def test_truncate(self):
+        """Test we truncate observations before twilight"""
+        detailer = detailers.TruncatePreTwiDetailer()
+        observation_array = ObservationArray(n=100)
+        n1 = np.size(observation_array)
+
+        observation_array["band"] = "r"
+        observation_array["exptime"] = 30.0
+
+        conditions = Conditions(mjd=3, survey_start_mjd=0)
+        conditions.current_band = "r"
+        # Have a ton of time, no obs should be cut
+        conditions.sun_n18_rising = 3.5
+        obs_out = detailer(observation_array, conditions)
+
+        assert np.size(obs_out) == n1
+
+        # cut down to not enough time
+        conditions.sun_n18_rising = 3.016
+
+        obs_out = detailer(observation_array, conditions)
+        n2 = np.size(obs_out)
+
+        # Now if we are in a different filter, should
+        # Have to lose a few more, but not all
+        conditions.current_band = "b"
+        obs_out = detailer(observation_array, conditions)
+
+        n3 = np.size(obs_out)
+
+        assert n1 > n2
+
+        assert n2 > n3
+
+        assert n3 > 0
+
+    def test_rollband(self):
+
+        orig_order = np.array(["u", "g", "r"])
+
+        observation_array = ObservationArray(n=3)
+        observation_array["band"] = ["u", "g", "r"]
+
+        # Test where no change should happen
+        detailer = detailers.RollBandMatchDetailer()
+        conditions = Conditions()
+        conditions.current_band = "u"
+        o1 = detailer(observation_array, conditions)
+        for bn, ob in zip(orig_order, o1["band"]):
+            assert bn == ob
+
+        # Test where things should roll
+        conditions.current_band = "r"
+        o2 = detailer(observation_array, conditions)
+
+        assert o2["band"][0] == "r"
+
+        for bn in orig_order:
+            assert bn in o2["band"]
+
 
 if __name__ == "__main__":
     unittest.main()
